from setuptools import setup

setup(
    name='automation-utilities',
    version='1.4.3',
    author='Hazem Oukal',
    description='Some automation tools',
    packages=['automation_utilities'],
    install_requires=['phonenumbers', 'names', 'requests'],
)
